@@ -1,5 +1,6 @@
 package urpm;
 
+# $Id: urpm.pm 271301 2010-11-22 00:50:49Z eugeni $
 
 no warnings 'utf8';
 use strict;
@@ -14,7 +15,7 @@ use urpm::md5sum;
 # perl_checker: require urpm::media
 # perl_checker: require urpm::parallel
 
-our $VERSION = 'v8.133.2';
+our $VERSION = '8.03';
 our @ISA = qw(URPM Exporter);
 our @EXPORT_OK = ('file_from_local_url', 'file_from_local_medium', 'is_local_medium');
 
@@ -35,8 +36,6 @@ urpm - Mageia perl tools to handle the urpmi database
 C<urpm> is used by urpmi executables to manipulate packages and media
 on a Mageia Linux distribution.
 
-It rely on L<URPM> for the lower level librpm bindings.
-
 =head2 The urpm class
 
 =over 4
@@ -53,7 +52,7 @@ sub xml_info_policies() { qw(never on-demand update-only always) }
 sub default_options {
     { 
 	'split-level' => 1,
-	'split-length' => 50,
+	'split-length' => 8,
 	'verify-rpm' => 1,
 	'post-clean' => 1,
 	'xml-info' => 'on-demand',
@@ -594,6 +593,7 @@ sub DESTROY {}
 
 1;
 
+__END__
 
 =back
 
@@ -602,10 +602,6 @@ sub DESTROY {}
 The L<URPM> package is used to manipulate at a lower level synthesis and rpm
 files.
 
-The L<rpmtools> package provides commands to generate synthesis and hdlist
-files (as well as other metadata): L<genhdlist2> and L<gendistrib> (a
-gendhlist2 wrapper handling a whole media set) from L<rpmtools> package.
-
 See also submodules: L<gurpmi>, L<urpm::args>, L<urpm::bug_report>,
 L<urpm::cdrom>, L<urpm::cfg>, L<urpm::download>, L<urpm::get_pkgs>,
 L<urpm::install>, L<urpm::ldap>, L<urpm::lock>, L<urpm::main_loop>,
@@ -621,7 +617,7 @@ Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2020 Mageia
+Copyright (C) 2011-2013 Mageia SA
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
